@@ -84,7 +84,7 @@ def copy_md(project, from_doc_file: str, to_project_file: str = "README.md"):
     
     1. github (to acquire more recent version since release)
     
-    2. dev docs, if exists (gold version in docs, not prototypes).
+    2. dev docs, iff exists (gold version in docs, not prototypes).
 
     Used by Sample-AI; Sample-Integration (nw-), Tutorial, Tutorial-3 (3 projects), Sample-Basic-Demo; Manager
 
@@ -146,6 +146,7 @@ def copy_md(project, from_doc_file: str, to_project_file: str = "README.md"):
             readme_lines_mkdocs = readme_file.readlines()    
         readme_lines_md = []
         in_mkdocs_block = False
+        do_process_code_block_titles = False
         db_line_num = 0
         for each_line in readme_lines_mkdocs:
             db_line_num += 1
@@ -192,8 +193,19 @@ def copy_md(project, from_doc_file: str, to_project_file: str = "README.md"):
                         r'(https://apilogicserver.github.io/Docs/\1)',
                         each_line
                     )
-                    each_line = each_line.replace('.md', '')
+                    if 'copilot' in each_line or 'Copilot' in each_line:  
+                        pass
+                    else:
+                        each_line = each_line.replace('.md', '')  # hmm... todo: find out why this exists
                     pass
+                if 'process_code_block_titles' in each_line:  # update front matter to get this
+                    do_process_code_block_titles = True
+                if do_process_code_block_titles and 'title=' in each_line:
+                    # extract the quoted text after 'title=' into title
+                    match = re.search(r'title\s*=\s*["\']([^"\']+)["\']', each_line)
+                    if match:
+                        title = match.group(1)
+                    readme_lines_md.append('**' + title + ':**\n')
                 readme_lines_md.append(each_line)
         with open(str(to_file), "w") as readme_file:
             readme_file.writelines(readme_lines_md)
@@ -290,10 +302,13 @@ def get_abs_db_url(msg, project: Project, is_auth: bool = False):
             else:
                 rtn_abs_db_url = f'sqlite:///{str(project.api_logic_server_dir_path.joinpath("prototypes/sample_ai/database/chatgpt/sample_ai_items.sqlite"))}'
                 # log.info('.. using installed nw sample database')
-        else:
+        else:  # for win, might be: sqlite:////C:\\Users\\val\\dev\\ApiLogicServer\\ApiLogicServer-dev\\org_git\\ApiLogicServer-src\\api_logic_server_cli\\database\\mcp.sqlite
             url = url_to_process[10: len(url_to_process)]
+            if url_to_process.startswith('sqlite:////c:'):
+                url = url_to_process[11: len(url_to_process)]
             rtn_abs_db_url = abspath(url)
             rtn_abs_db_url = 'sqlite:///' + rtn_abs_db_url
+            pass
     elif url_to_process == 'sqlsvr-sample':  # work-around - VSCode run config arg parsing
         rtn_abs_db_url = 'mssql+pyodbc://sa:Posey3861@localhost:1433/SampleDB?driver=ODBC+Driver+18+for+SQL+Server&trusted_connection=no&Encrypt=no'
     elif url_to_process == 'sqlsvr-nwlogic':  # work-around - VSCode run config arg parsing
@@ -402,10 +417,10 @@ def does_file_contain(search_for: str, in_file: str) -> bool:
         return found
 
 def replace_string_in_file(search_for: str, replace_with: str, in_file: str):
-    with open(Path(in_file), 'r') as file:
+    with open(Path(in_file), 'r', encoding="utf-8") as file:
         file_data = file.read()
         file_data = file_data.replace(search_for, replace_with)
-    with open(in_file, 'w') as file:
+    with open(in_file, 'w', encoding="utf-8") as file:
         file.write(file_data)
 
 def assign_value_to_key_in_file(key: str, value: any, in_file: str):
