@@ -81,7 +81,7 @@ try:  # this is just for WebGenAI
 
     # Add the file handler to the logger
     log.addHandler(file_handler)
-    log.setLevel(logging.DEBUG)
+    # log.setLevel(logging.DEBUG)
     
 except Exception as exc:
     pass # this is just for WebGenAI, ok to ignore error
@@ -906,10 +906,11 @@ def call_chatgpt(messages: List[Dict[str, str]], api_version: str, using: str, r
         request_path.parent.mkdir(parents=True, exist_ok=True)
         return request_path
     
-    def string_to_lines(dict_long_string: dict) -> dict:
+    def string_to_lines(dict_long_string: list) -> dict:
         result = dict_long_string
-        if isinstance(result[1]['content'], str):
-            result[1]['content'] = result[1]['content'].split('\n')
+        if len(result) > 1:
+            if isinstance(result[1]['content'], str):
+                result[1]['content'] = result[1]['content'].split('\n')
         return result
 
     try:
@@ -932,7 +933,7 @@ def call_chatgpt(messages: List[Dict[str, str]], api_version: str, using: str, r
         messages_for_print = string_to_lines(messages_for_print)  # Removed to avoid altering messages
         with open(request_path, "w") as request_file:  # save for debug
             json.dump(messages_for_print, request_file, indent=4)
-        log.info(f'.. saved request: {using}/request.json')
+        log.debug(f'.. saved request: {using}/request.json')
         client = get_ai_client()
         # response_format = "json_object" if wg_response else {"type": "text"}
         completion = client.beta.chat.completions.parse(
@@ -941,7 +942,7 @@ def call_chatgpt(messages: List[Dict[str, str]], api_version: str, using: str, r
             # temperature=self.project.genai_temperature,  values .1 and .7 made students / charges fail
             model=model  # for own model, use "ft:gpt-4o-2024-08-06:personal:logicbank:ARY904vS" 
         )
-        log.info(f'ChatGPT ({str(int(time.time() - start_time))} secs) - response at: system/genai/temp/chatgpt_original.response')
+        log.debug(f'OpenAI ({str(int(time.time() - start_time))} secs) - response at: system/genai/temp/chatgpt_original.response')
         
         data = completion.choices[0].message.content
 
@@ -966,58 +967,59 @@ def call_chatgpt(messages: List[Dict[str, str]], api_version: str, using: str, r
         log.error(f"\n\nError: ChatGPT call failed\n- please see https://apilogicserver.github.io/Docs/WebGenAI-CLI/#configuratio\n{inst}\n\n")
         sys.exit(1)
 
-def get_manager_path(use_env: bool = False) -> Path:
+def get_manager_path(project: object = None) -> Path:
     """ Checks cwd, parent, and grandparent for system/genai
 
     * Possibly could add cli arg later
 
     Args:
-        use_env: bool if cannot find manager from project, use install location
+        project: instance of Project - best practice is caller provides, so can use install loc if cannot find manager
 
     Returns:
         Path: Manager path (contains system/genai)
     """
 
-    if use_env and os.getenv("APILOGICSERVER_HOME") is not None:
-        result_path = Path(os.getenv("APILOGICSERVER_HOME")).joinpath('api_logic_server_cli/prototypes/manager')
-        return result_path
+    if project is not None:
+        result_path = project.manager_path
+        check_system_genai = result_path.joinpath('system/genai/temp')    
+        if check_system_genai.exists():
+            return result_path
+        return result_path # todo - verify what this does (should not occur)
 
     result_path = Path(os.getcwd())  # normal case - project at manager root
-    check_system_genai = result_path.joinpath('system/genai')    
+    check_system_genai = result_path.joinpath('system/genai/temp')    
     if check_system_genai.exists():
         return result_path
     
     result_path = result_path.parent  # try pwd parent
-    check_system_genai = result_path.joinpath('system/genai')
+    check_system_genai = result_path.joinpath('system/genai/temp')
     if check_system_genai.exists():
         return result_path
     
     result_path = result_path.parent  # try pwd grandparent
-    check_system_genai = result_path.joinpath('system/genai')
+    check_system_genai = result_path.joinpath('system/genai/temp')
     if check_system_genai.exists():
         return result_path
     
     result_path = result_path.parent 
-    check_system_genai = result_path.joinpath('system/genai')
+    check_system_genai = result_path.joinpath('system/genai/temp')
     if check_system_genai.exists():
         return result_path
     
     result_path = result_path.parent  
-    check_system_genai = result_path.joinpath('system/genai')
+    check_system_genai = result_path.joinpath('system/genai/temp')
     if check_system_genai.exists():
         return result_path
     
     result_path = result_path.parent  
-    check_system_genai = result_path.joinpath('system/genai')
+    check_system_genai = result_path.joinpath('system/genai/temp')
     if check_system_genai.exists():
         return result_path
 
     result_path = result_path.parent  # try ancestors - this is for import testing
-    check_system_genai = result_path.joinpath('system/genai')
+    check_system_genai = result_path.joinpath('system/genai/temp')
 
     if not check_system_genai.exists():
-        if use_env:
-            result_path = Path(create_utils.get_api_logic_server_dir()).joinpath('prototypes/manager')
         check_system_genai.exists(), f"Manager Directory not found and APILOGICSERVER_HOME not set: {check_system_genai}"
     return result_path
 
