@@ -29,6 +29,11 @@ The ctor then calls `create_resource_list`, to create the `resource_list`
 
 import sys, logging, inspect, builtins, os, argparse, tempfile, atexit, shutil, io
 import traceback
+try:
+    from importlib.metadata import version as get_version
+except ImportError:
+    # Python < 3.8 fallback
+    from importlib_metadata import version as get_version
 
 import safrs
 from sqlalchemy import CHAR, Column, DateTime, Float, ForeignKey, Index, Integer, String, TIMESTAMP, Table, Text, UniqueConstraint, text
@@ -44,17 +49,23 @@ from io import StringIO
 from sqlalchemy.engine import create_engine
 from sqlalchemy.schema import MetaData
 from flask_cors import CORS
-from sqlacodegen_wrapper.sqlacodegen.sqlacodegen.codegen import CodeGenerator
-from api_logic_server_cli.create_from_model.model_creation_services import ModelCreationServices
+from .sqlacodegen.sqlacodegen.codegen import CodeGenerator
+from .sqlacodegen.sqlacodegen.main import main as codegen
+from typing import TYPE_CHECKING
+if TYPE_CHECKING:
+    from api_logic_server_cli.create_from_model.model_creation_services import ModelCreationServices
 from pathlib import Path
 from shutil import copyfile
 import os, sys
 from pathlib import Path
 from os.path import abspath
 from api_logic_server_cli.cli_args_project import Project
-import oracledb
-
 log = logging.getLogger(__name__)
+try:
+    import oracledb
+except ImportError:
+    log.error("oracledb dll not found, Oracle support disabled")
+    oracledb = None
 
 MODEL_DIR = tempfile.mkdtemp()  # directory where the generated models.py will be saved
 on_import = False
@@ -91,8 +102,11 @@ def get_args():
     args = parser.parse_args()
 
     if args.version:
-        version = pkg_resources.get_distribution("sqlacodegen").parsed_version # noqa: F821
-        log.debug(version.public)
+        try:
+            version_str = get_version("sqlacodegen")
+            log.debug(version_str)
+        except Exception:
+            log.debug("sqlacodegen version not found")
         exit()
     if not args.url:
         log.debug("You must supply a url\n", file=sys.stderr)
@@ -133,7 +147,7 @@ uri_info = """Examples:
   ApiLogicServer create-and-run --db_url=mssql+pyodbc://sa:Posey3861@localhost:1433/NORTHWND?driver=ODBC+Driver+17+for+SQL+Server&trusted_connection=no
   ApiLogicServer create-and-run --db_url=postgresql://postgres:p@10.0.0.234/postgres
   ApiLogicServer create --project_name=my_schema --db_url=postgresql://postgres:p@localhost/my_schema
-  ApiLogicServer create --db_url=postgresql+psycopg2://postgres:password@localhost:5432/postgres?options=-csearch_path%3Dmy_db_schema
+  ApiLogicServer create --db_url=postgresql://postgres:password@localhost:5432/postgres?options=-csearch_path%3Dmy_db_schema
   ApiLogicServer create --project_name=Chinook \
     --host=ApiLogicServer.pythonanywhere.com --port= \
     --db_url=mysql+pymysql://ApiLogicServer:***@ApiLogicServer.mysql.pythonanywhere-services.com/ApiLogicServer$Chinook
@@ -199,7 +213,13 @@ def create_models_memstring(args) -> str:
 
     if os.getenv('APILOGICSERVER_ORACLE_THICK'):
         oracledb.init_oracle_client(lib_dir=os.getenv('APILOGICSERVER_ORACLE_THICK'))
-    engine = create_engine(args.url)  # type _engine.Engine
+    
+    # For Python 3.13+, force PostgreSQL URLs to use psycopg3 dialect
+    engine_url = args.url
+    if sys.version_info >= (3, 13) and engine_url.startswith('postgresql://'):
+        engine_url = engine_url.replace('postgresql://', 'postgresql+psycopg://', 1)
+    
+    engine = create_engine(engine_url)  # type _engine.Engine
 
     metadata = MetaData()
     if os.getenv('APILOGICSERVER_ORACLE_THICK'):
@@ -292,7 +312,7 @@ if on_import:
             models_f.write(models)
         # atexit.register(lambda : shutil.rmtree(MODEL_DIR))
 
-    import models
+    import models  # type: ignore  # dynamically created module
 
 
 def start_api(HOST="0.0.0.0", PORT=5000):
@@ -338,7 +358,7 @@ if __name__ == "__main__":
 
 
 
-def create_models_py(model_creation_services: ModelCreationServices, abs_db_url: str, project_directory: str):
+def create_models_py(model_creation_services: "ModelCreationServices", abs_db_url: str, project_directory: str):
     """
     Create `models.py` (using sqlacodegen, via this wrapper at create_models_py() ).
 
